# rich-LogConsole [![GitHub Repo stars](https://img.shields.io/github/stars/WankkoRee/rich-LogConsole?label=Github%20Stars&style=social "GitHub Repo stars")](https://github.com/WankkoRee/rich-LogConsole) [![GitHub Downloads](https://img.shields.io/github/downloads/WankkoRee/rich-LogConsole/total?label=GitHub%20Downloads&logo=github&style=social)](https://github.com/WankkoRee/rich-LogConsole/releases) [![PyPI Downloads](https://img.shields.io/pypi/dm/rich-LogConsole?label=PyPI%20Downloads&logo=pypi&style=social)](https://pypi.org/project/rich-LogConsole/)

一个实现了在一定高度自动滚动的`rich`日志组件，有两种刷新方式，建议配合Layout、Panel等组件使用。

## install

```shell
pip install rich-LogConsole
```

## update

[![GitHub release (latest by date)](https://img.shields.io/github/v/release/WankkoRee/rich-LogConsole?color=%23fff&label=GitHub&logo=github&logoColor=%23fff)](https://github.com/WankkoRee/rich-LogConsole/releases) [![PyPI](https://img.shields.io/pypi/v/rich-LogConsole?color=%23fff&label=PyPI&logo=pypi&logoColor=%23fff)](https://pypi.org/project/rich-LogConsole/)

```shell
pip install --upgrade rich-LogConsole
```

## use

```python
from rich_LogConsole import LogConsoleScroll, LogConsoleOverwrite
```

## demo

见[demo.py](https://github.com/WankkoRee/rich-LogConsole/blob/master/tests/demo.py)

![screenshot](https://raw.githubusercontent.com/WankkoRee/rich-LogConsole/master/screenshot.gif "screenshot")

## License

[![GitHub License](https://img.shields.io/github/license/WankkoRee/rich-LogConsole?color=%23f7f7f7&logo=gnu&logoColor=%23fff&style=for-the-badge)](https://github.com/WankkoRee/rich-LogConsole/blob/master/LICENSE)
